[libcamera-devel] [PATCH 03/10] libcamera: ipa: raspberrypi: agc: Rename method to divideUpExposure

David Plowman david.plowman at raspberrypi.com
Mon Nov 16 17:49:11 CET 2020


The method formerly known as divvyupExposure is given a more
understandable name.

Signed-off-by: David Plowman <david.plowman at raspberrypi.com>
---
 src/ipa/raspberrypi/controller/rpi/agc.cpp | 8 ++++----
 src/ipa/raspberrypi/controller/rpi/agc.hpp | 2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/ipa/raspberrypi/controller/rpi/agc.hpp b/src/ipa/raspberrypi/controller/rpi/agc.hpp
index 5a02df4e..2442fc03 100644
--- a/src/ipa/raspberrypi/controller/rpi/agc.hpp
+++ b/src/ipa/raspberrypi/controller/rpi/agc.hpp
@@ -89,7 +89,7 @@ private:
 	bool applyDigitalGain(Metadata *image_metadata, double gain,
 			      double target_Y);
 	void filterExposure(bool desaturate);
-	void divvyupExposure();
+	void divideUpExposure();
 	void writeAndFinish(Metadata *image_metadata, bool desaturate);
 	AgcMeteringMode *metering_mode_;
 	AgcExposureMode *exposure_mode_;
diff --git a/src/ipa/raspberrypi/controller/rpi/agc.cpp b/src/ipa/raspberrypi/controller/rpi/agc.cpp
index c4379b99..d29b1156 100644
--- a/src/ipa/raspberrypi/controller/rpi/agc.cpp
+++ b/src/ipa/raspberrypi/controller/rpi/agc.cpp
@@ -225,7 +225,7 @@ void Agc::SwitchMode([[maybe_unused]] CameraMode const &camera_mode,
 	// write the results into the metadata we've been given.
 	if (status_.total_exposure_value) {
 		housekeepConfig();
-		divvyupExposure();
+		divideUpExposure();
 		writeAndFinish(metadata, false);
 	}
 }
@@ -304,9 +304,9 @@ void Agc::Process(StatisticsPtr &stats, Metadata *image_metadata)
 	bool desaturate = applyDigitalGain(image_metadata, gain, target_Y);
 	// The results have to be filtered so as not to change too rapidly.
 	filterExposure(desaturate);
 	// The last thing is to divvy up the exposure value into a shutter time
 	// and analogue_gain, according to the current exposure mode.
-	divvyupExposure();
+	divideUpExposure();
 	// Finally advertise what we've done.
 	writeAndFinish(image_metadata, desaturate);
 }
@@ -545,7 +545,7 @@ void Agc::filterExposure(bool desaturate)
 			   << " no dg " << filtered_.total_exposure_no_dg;
 }
 
-void Agc::divvyupExposure()
+void Agc::divideUpExposure()
 {
 	// Sending the fixed shutter/gain cases through the same code may seem
 	// unnecessary, but it will make more sense when extend this to cover
@@ -304,9 +304,9 @@ void Agc::Process(StatisticsPtr &stats, Metadata *image_metadata)
 	// The results have to be filtered so as not to change too rapidly.
 	filterExposure(desaturate);
-	// The last thing is to divvy up the exposure value into a shutter time
+	// The last thing is to divide up the exposure value into a shutter time
 	// and analogue_gain, according to the current exposure mode.
-- 
2.20.1



More information about the libcamera-devel mailing list